=== modified file 'bzrlib/tests/blackbox/test_add.py'
--- bzrlib/tests/blackbox/test_add.py	2012-01-04 17:12:42 +0000
+++ bzrlib/tests/blackbox/test_add.py	2012-01-05 17:46:44 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007, 2009, 2010, 2011 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -154,8 +154,8 @@
         new_tree = self.make_branch_and_tree('new')
         self.build_tree(['new/a', 'new/b/', 'new/b/c', 'd'])
 
-        os.chdir('new')
-        out, err = self.run_bzr('add --file-ids-from ../base')
+        out, err = self.run_bzr('add --file-ids-from ../base',
+                                working_dir='new')
         self.assertEqual('', err)
         self.assertEqualDiff('adding a w/ file id from a\n'
                              'adding b w/ file id from b\n'
@@ -175,14 +175,14 @@
         new_tree = self.make_branch_and_tree('new')
         self.build_tree(['new/c', 'new/d'])
 
-        os.chdir('new')
-        out, err = self.run_bzr('add --file-ids-from ../base/b')
+        out, err = self.run_bzr('add --file-ids-from ../base/b',
+                                working_dir='new')
         self.assertEqual('', err)
         self.assertEqualDiff('adding c w/ file id from b/c\n'
                              'adding d w/ file id from b/d\n',
                              out)
 
-        new_tree = new_tree.bzrdir.open_workingtree()
+        new_tree = new_tree.bzrdir.open_workingtree('new')
         self.assertEqual(base_tree.path2id('b/c'), new_tree.path2id('c'))
         self.assertEqual(base_tree.path2id('b/d'), new_tree.path2id('d'))
 

=== modified file 'bzrlib/tests/blackbox/test_bound_branches.py'
--- bzrlib/tests/blackbox/test_bound_branches.py	2011-09-26 15:21:01 +0000
+++ bzrlib/tests/blackbox/test_bound_branches.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,14 +17,12 @@
 
 """Tests of bound branches (binding, unbinding, commit, etc) command."""
 
-import os
-
 from bzrlib import (
+    branch,
+    bzrdir,
     errors,
     tests,
     )
-from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
 from bzrlib.tests import script
 
 
@@ -42,40 +40,38 @@
         child_tree = branch.create_checkout('child')
 
         self.check_revno(1, 'child')
-        d = BzrDir.open('child')
+        d = bzrdir.BzrDir.open('child')
         self.assertNotEqual(None, d.open_branch().get_master_branch())
 
         return base_tree, child_tree
 
     def check_revno(self, val, loc='.'):
         self.assertEqual(
-            val, BzrDir.open(loc).open_branch().last_revision_info()[0])
+            val, bzrdir.BzrDir.open(loc).open_branch().last_revision_info()[0])
 
     def test_simple_binding(self):
         tree = self.make_branch_and_tree('base')
         self.build_tree(['base/a', 'base/b'])
         tree.add('a', 'b')
         tree.commit(message='init')
-        branch = tree.branch
 
         tree.bzrdir.sprout('child')
 
-        os.chdir('child')
-        self.run_bzr('bind ../base')
+        self.run_bzr('bind ../base', working_dir='child')
 
-        d = BzrDir.open('')
+        d = bzrdir.BzrDir.open('child')
         self.assertNotEqual(None, d.open_branch().get_master_branch())
 
-        self.run_bzr('unbind')
+        self.run_bzr('unbind', working_dir='child')
         self.assertEqual(None, d.open_branch().get_master_branch())
 
-        self.run_bzr('unbind', retcode=3)
+        self.run_bzr('unbind', retcode=3, working_dir='child')
 
     def test_bind_branch6(self):
         branch1 = self.make_branch('branch1', format='dirstate-tags')
-        os.chdir('branch1')
-        error = self.run_bzr('bind', retcode=3)[1]
-        self.assertContainsRe(error, 'no previous location known')
+        error = self.run_bzr('bind', retcode=3, working_dir='branch1')[1]
+        self.assertEndsWith(
+            error, 'No location supplied and no previous location known\n')
 
     def setup_rebind(self, format):
         branch1 = self.make_branch('branch1')
@@ -85,16 +81,16 @@
 
     def test_rebind_branch6(self):
         self.setup_rebind('dirstate-tags')
-        os.chdir('branch2')
-        self.run_bzr('bind')
-        b = Branch.open('.')
-        self.assertContainsRe(b.get_bound_location(), '\/branch1\/$')
+        self.run_bzr('bind', working_dir='branch2')
+        b = branch.Branch.open('branch2')
+        self.assertEndsWith(b.get_bound_location(), '/branch1/')
 
     def test_rebind_branch5(self):
         self.setup_rebind('knit')
-        os.chdir('branch2')
-        error = self.run_bzr('bind', retcode=3)[1]
-        self.assertContainsRe(error, 'old locations')
+        error = self.run_bzr('bind', retcode=3, working_dir='branch2')[1]
+        self.assertEndsWith(
+            error, 'No location supplied.  This format does not remember'
+            ' old locations.\n')
 
     def test_bound_commit(self):
         child_tree = self.create_branches()[1]
@@ -134,9 +130,8 @@
 
         child2_tree = child_tree.bzrdir.sprout('child2').open_workingtree()
 
-        os.chdir('child2')
         # Double binding succeeds, but committing to child2 should fail
-        self.run_bzr('bind ../child')
+        self.run_bzr('bind ../child', working_dir='child2')
 
         self.assertRaises(errors.CommitToDoubleBoundBranch,
                 child2_tree.commit, message='child2', allow_pointless=True)
@@ -152,12 +147,11 @@
         self.check_revno(2, 'base')
 
         self.check_revno(1, 'child')
-        os.chdir('child')
-        self.run_bzr("commit -m child", retcode=3)
-        self.check_revno(1)
-        self.run_bzr('unbind')
+        self.run_bzr("commit -m child", retcode=3, working_dir='child')
+        self.check_revno(1, 'child')
+        self.run_bzr('unbind', working_dir='child')
         child_tree.commit(message='child')
-        self.check_revno(2)
+        self.check_revno(2, 'child')
 
     def test_commit_remote_bound(self):
         # It is not possible to commit to a branch
@@ -165,14 +159,13 @@
         base_tree, child_tree = self.create_branches()
         base_tree.bzrdir.sprout('newbase')
 
-        os.chdir('base')
         # There is no way to know that B has already
         # been bound by someone else, otherwise it
         # might be nice if this would fail
-        self.run_bzr('bind ../newbase')
+        self.run_bzr('bind ../newbase', working_dir='base')
 
-        os.chdir('../child')
-        self.run_bzr('commit -m failure --unchanged', retcode=3)
+        self.run_bzr('commit -m failure --unchanged', retcode=3,
+                     working_dir='child')
 
     def test_pull_updates_both(self):
         base_tree = self.create_branches()[0]
@@ -181,13 +174,11 @@
         newchild_tree.commit(message='newchild')
         self.check_revno(2, 'newchild')
 
-        os.chdir('child')
         # The pull should succeed, and update
         # the bound parent branch
-        self.run_bzr('pull ../newchild')
-        self.check_revno(2)
-
-        self.check_revno(2, '../base')
+        self.run_bzr('pull ../newchild', working_dir='child')
+        self.check_revno(2, 'child')
+        self.check_revno(2, 'base')
 
     def test_pull_local_updates_local(self):
         base_tree = self.create_branches()[0]
@@ -196,67 +187,59 @@
         newchild_tree.commit(message='newchild')
         self.check_revno(2, 'newchild')
 
-        os.chdir('child')
         # The pull should succeed, and update
         # the bound parent branch
-        self.run_bzr('pull ../newchild --local')
-        self.check_revno(2)
-
-        self.check_revno(1, '../base')
+        self.run_bzr('pull ../newchild --local', working_dir='child')
+        self.check_revno(2, 'child')
+        self.check_revno(1, 'base')
 
     def test_bind_diverged(self):
         base_tree, child_tree = self.create_branches()
         base_branch = base_tree.branch
         child_branch = child_tree.branch
 
-        os.chdir('child')
-        self.run_bzr('unbind')
+        self.run_bzr('unbind', working_dir='child')
 
         child_tree.commit(message='child', allow_pointless=True)
-        self.check_revno(2)
+        self.check_revno(2, 'child')
 
-        os.chdir('..')
         self.check_revno(1, 'base')
         base_tree.commit(message='base', allow_pointless=True)
         self.check_revno(2, 'base')
 
-        os.chdir('child')
         # These branches have diverged, but bind should succeed anyway
-        self.run_bzr('bind ../base')
+        self.run_bzr('bind ../base', working_dir='child')
 
         # This should turn the local commit into a merge
         child_tree.update()
         child_tree.commit(message='merged')
-        self.check_revno(3)
-
-        self.assertEquals(
-            child_tree.branch.last_revision(),
-            base_tree.branch.last_revision())
+        self.check_revno(3, 'child')
+        self.assertEquals(child_tree.branch.last_revision(),
+                          base_tree.branch.last_revision())
 
     def test_bind_parent_ahead(self):
         base_tree = self.create_branches()[0]
 
-        os.chdir('child')
-        self.run_bzr('unbind')
+        self.run_bzr('unbind', working_dir='child')
 
         base_tree.commit(message='base', allow_pointless=True)
 
-        self.check_revno(1)
-        self.run_bzr('bind ../base')
+        self.check_revno(1, 'child')
+        self.run_bzr('bind ../base', working_dir='child')
 
         # binding does not pull data:
-        self.check_revno(1)
-        self.run_bzr('unbind')
+        self.check_revno(1, 'child')
+        self.run_bzr('unbind', working_dir='child')
 
         # Check and make sure it also works if parent is ahead multiple
         base_tree.commit(message='base 3', allow_pointless=True)
         base_tree.commit(message='base 4', allow_pointless=True)
         base_tree.commit(message='base 5', allow_pointless=True)
-        self.check_revno(5, '../base')
+        self.check_revno(5, 'base')
 
-        self.check_revno(1)
-        self.run_bzr('bind ../base')
-        self.check_revno(1)
+        self.check_revno(1, 'child')
+        self.run_bzr('bind ../base', working_dir='child')
+        self.check_revno(1, 'child')
 
     def test_bind_child_ahead(self):
         # test binding when the master branches history is a prefix of the
@@ -264,61 +247,34 @@
         # be altered
         child_tree = self.create_branches()[1]
 
-        os.chdir('child')
-        self.run_bzr('unbind')
+        self.run_bzr('unbind', working_dir='child')
         child_tree.commit(message='child', allow_pointless=True)
-        self.check_revno(2)
-        self.check_revno(1, '../base')
+        self.check_revno(2, 'child')
+        self.check_revno(1, 'base')
 
-        self.run_bzr('bind ../base')
-        self.check_revno(1, '../base')
+        self.run_bzr('bind ../base', working_dir='child')
+        self.check_revno(1, 'base')
 
         # Check and make sure it also works if child is ahead multiple
-        self.run_bzr('unbind')
+        self.run_bzr('unbind', working_dir='child')
         child_tree.commit(message='child 3', allow_pointless=True)
         child_tree.commit(message='child 4', allow_pointless=True)
         child_tree.commit(message='child 5', allow_pointless=True)
-        self.check_revno(5)
+        self.check_revno(5, 'child')
 
-        self.check_revno(1, '../base')
-        self.run_bzr('bind ../base')
-        self.check_revno(1, '../base')
+        self.check_revno(1, 'base')
+        self.run_bzr('bind ../base', working_dir='child')
+        self.check_revno(1, 'base')
 
     def test_bind_fail_if_missing(self):
         """We should not be able to bind to a missing branch."""
         tree = self.make_branch_and_tree('tree_1')
         tree.commit('dummy commit')
-        self.run_bzr_error(['Not a branch.*no-such-branch/'], ['bind', '../no-such-branch'],
-                            working_dir='tree_1')
+        self.run_bzr_error(['Not a branch.*no-such-branch/'],
+                           ['bind', '../no-such-branch'],
+                           working_dir='tree_1')
         self.assertIs(None, tree.branch.get_bound_location())
 
-    def test_bind_nick(self):
-        """Bind should not update implicit nick."""
-        base = self.make_branch_and_tree('base')
-        child = self.make_branch_and_tree('child')
-        os.chdir('child')
-        self.assertEqual(child.branch.nick, 'child')
-        self.assertEqual(child.branch.get_config().has_explicit_nickname(),
-            False)
-        self.run_bzr('bind ../base')
-        self.assertEqual(child.branch.nick, base.branch.nick)
-        self.assertEqual(child.branch.get_config().has_explicit_nickname(),
-            False)
-
-    def test_bind_explicit_nick(self):
-        """Bind should update explicit nick."""
-        base = self.make_branch_and_tree('base')
-        child = self.make_branch_and_tree('child')
-        os.chdir('child')
-        child.branch.nick = "explicit_nick"
-        self.assertEqual(child.branch.nick, "explicit_nick")
-        self.assertEqual(child.branch.get_config()._get_explicit_nickname(),
-            "explicit_nick")
-        self.run_bzr('bind ../base')
-        self.assertEqual(child.branch.nick, base.branch.nick)
-        self.assertEqual(child.branch.get_config()._get_explicit_nickname(),
-            base.branch.nick)
-
     def test_commit_after_merge(self):
         base_tree, child_tree = self.create_branches()
 
@@ -347,13 +303,9 @@
 
         # Commit should succeed, and cause merged revisions to
         # be pulled into base
-        os.chdir('child')
-        self.run_bzr(['commit', '-m', 'merge other'])
-
-        self.check_revno(2)
-
-        self.check_revno(2, '../base')
-
+        self.run_bzr(['commit', '-m', 'merge other'], working_dir='child')
+        self.check_revno(2, 'child')
+        self.check_revno(2, 'base')
         self.assertTrue(base_tree.branch.repository.has_revision(new_rev_id))
 
     def test_pull_overwrite(self):
@@ -380,12 +332,11 @@
         self.check_revno(2, 'child')
         self.check_revno(2, 'base')
 
-        os.chdir('child')
-        self.run_bzr('pull --overwrite ../other')
+        self.run_bzr('pull --overwrite ../other', working_dir='child')
 
         # both the local and master should have been updated.
-        self.check_revno(4)
-        self.check_revno(4, '../base')
+        self.check_revno(4, 'child')
+        self.check_revno(4, 'base')
 
     def test_bind_directory(self):
         """Test --directory option"""
@@ -396,7 +347,7 @@
         branch = tree.branch
         tree.bzrdir.sprout('child')
         self.run_bzr('bind --directory=child base')
-        d = BzrDir.open('child')
+        d = bzrdir.BzrDir.open('child')
         self.assertNotEqual(None, d.open_branch().get_master_branch())
         self.run_bzr('unbind -d child')
         self.assertEqual(None, d.open_branch().get_master_branch())

=== modified file 'bzrlib/tests/blackbox/test_branch.py'
--- bzrlib/tests/blackbox/test_branch.py	2012-01-02 10:24:02 +0000
+++ bzrlib/tests/blackbox/test_branch.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2011 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,9 +25,9 @@
     controldir,
     errors,
     revision as _mod_revision,
+    tests,
     )
 from bzrlib.repofmt.knitrepo import RepositoryFormatKnit1
-from bzrlib.tests import TestCaseWithTransport
 from bzrlib.tests import (
     fixtures,
     test_server,
@@ -43,7 +43,7 @@
 from bzrlib.workingtree import WorkingTree
 
 
-class TestBranch(TestCaseWithTransport):
+class TestBranch(tests.TestCaseWithTransport):
 
     def example_branch(self, path='.', format=None):
         tree = self.make_branch_and_tree(path, format=format)
@@ -83,7 +83,8 @@
         self.assertEqual('', err)
         out,err = self.run_bzr('branch a file:b,branch=orig', retcode=3)
         self.assertEqual('', out)
-        self.assertEqual('bzr: ERROR: Already a branch: "file:b,branch=orig".\n', err)
+        self.assertEqual(
+            'bzr: ERROR: Already a branch: "file:b,branch=orig".\n', err)
 
     def test_from_colocated(self):
         """Branch from a colocated branch into a regular branch."""
@@ -113,7 +114,7 @@
             else:
                 corrupt = '\xFF'
             f.write(corrupt) # make sure we corrupt something
-        self.run_bzr_error(['Corruption while decompressing repository file'], 
+        self.run_bzr_error(['Corruption while decompressing repository file'],
                             'branch a b', retcode=3)
 
     def test_branch_switch_no_branch(self):
@@ -160,7 +161,8 @@
         #  => new branch will be created and checkout bound to the new branch
         self.example_branch('a')
         self.run_bzr('checkout a current')
-        out, err = self.run_bzr('branch --switch ../a ../b', working_dir='current')
+        out, err = self.run_bzr('branch --switch ../a ../b',
+                                working_dir='current')
         a = branch.Branch.open('a')
         b = branch.Branch.open('b')
         self.assertEqual(a.last_revision(), b.last_revision())
@@ -174,7 +176,8 @@
         #     the new branch
         self.example_branch('a')
         self.run_bzr('checkout --lightweight a current')
-        out, err = self.run_bzr('branch --switch ../a ../b', working_dir='current')
+        out, err = self.run_bzr('branch --switch ../a ../b',
+                                working_dir='current')
         a = branch.Branch.open('a')
         b = branch.Branch.open('b')
         self.assertEqual(a.last_revision(), b.last_revision())
@@ -340,16 +343,16 @@
         new_branch.repository.get_revision('rev-2')
 
 
-class TestBranchStacked(TestCaseWithTransport):
+class TestBranchStacked(tests.TestCaseWithTransport):
     """Tests for branch --stacked"""
 
     def assertRevisionInRepository(self, repo_path, revid):
-        """Check that a revision is in a repository, disregarding stacking."""
+        """Check that a revision is in a repo, disregarding stacking."""
         repo = bzrdir.BzrDir.open(repo_path).open_repository()
         self.assertTrue(repo.has_revision(revid))
 
     def assertRevisionNotInRepository(self, repo_path, revid):
-        """Check that a revision is not in a repository, disregarding stacking."""
+        """Check that a revision is not in a repo, disregarding stacking."""
         repo = bzrdir.BzrDir.open(repo_path).open_repository()
         self.assertFalse(repo.has_revision(revid))
 
@@ -427,7 +430,8 @@
             trunk_tree.branch.base, err)
         self.assertRevisionNotInRepository('newbranch', original_revid)
         new_branch = branch.Branch.open('newbranch')
-        self.assertEqual(trunk_tree.branch.base, new_branch.get_stacked_on_url())
+        self.assertEqual(trunk_tree.branch.base,
+                         new_branch.get_stacked_on_url())
 
     def test_branch_stacked_from_smart_server(self):
         # We can branch stacking on a smart server
@@ -468,7 +472,7 @@
             err)
 
 
-class TestSmartServerBranching(TestCaseWithTransport):
+class TestSmartServerBranching(tests.TestCaseWithTransport):
 
     def test_branch_from_trivial_branch_to_same_server_branch_acceptance(self):
         self.setup_smart_server_with_call_log()
@@ -593,10 +597,11 @@
         self.assertFalse(t.has('remote/file'))
 
 
-class TestDeprecatedAliases(TestCaseWithTransport):
+class TestDeprecatedAliases(tests.TestCaseWithTransport):
 
     def test_deprecated_aliases(self):
-        """bzr branch can be called clone or get, but those names are deprecated.
+        """bzr branch can be called clone or get, but those names are
+        deprecated.
 
         See bug 506265.
         """

=== modified file 'bzrlib/tests/blackbox/test_cat.py'
--- bzrlib/tests/blackbox/test_cat.py	2011-12-14 21:57:37 +0000
+++ bzrlib/tests/blackbox/test_cat.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2011 Canonical Ltd
+# Copyright (C) 2005-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,6 @@
 """Black-box tests for bzr cat.
 """
 
-import os
-
 from bzrlib import tests
 from bzrlib.tests.matchers import ContainsNoVfsCalls
 from bzrlib.transport import memory
@@ -31,45 +29,45 @@
         tree = self.make_branch_and_tree('branch')
         self.build_tree_contents([('branch/a', 'foo\n')])
         tree.add('a')
-        os.chdir('branch')
         # 'bzr cat' without an option should cat the last revision
-        self.run_bzr(['cat', 'a'], retcode=3)
+        self.run_bzr(['cat', 'a'], retcode=3, working_dir='branch')
 
         tree.commit(message='1')
-        self.build_tree_contents([('a', 'baz\n')])
+        self.build_tree_contents([('branch/a', 'baz\n')])
 
-        self.assertEquals(self.run_bzr(['cat', 'a'])[0], 'foo\n')
+        self.assertEquals('foo\n',
+                          self.run_bzr(['cat', 'a'], working_dir='branch')[0])
 
         # On Windows, we used to have a bug where newlines got changed into
         # crlf, whereas cat ought to write out the file exactly as it's
         # recorded (by default.)  That problem can't be reproduced in-process,
         # so we need just one test here that 
-        self.assertEquals(self.run_bzr_subprocess(['cat', 'a'])[0], 'foo\n')
+        self.assertEquals('foo\n',
+                          self.run_bzr_subprocess(['cat', 'a'],
+                                                  working_dir='branch')[0])
 
         tree.commit(message='2')
-        self.assertEquals(self.run_bzr(['cat', 'a'])[0], 'baz\n')
-        self.assertEquals(self.run_bzr(
-            ['cat', 'a', '-r', '1'])[0],
-            'foo\n')
-        self.assertEquals(self.run_bzr(
-            ['cat', 'a', '-r', '-1'])[0],
-            'baz\n')
+        self.assertEquals(
+            'baz\n', self.run_bzr(['cat', 'a'], working_dir='branch')[0])
+        self.assertEquals(
+            'foo\n', self.run_bzr(['cat', 'a', '-r', '1'],
+                                  working_dir='branch')[0])
+        self.assertEquals(
+            'baz\n', self.run_bzr(['cat', 'a', '-r', '-1'],
+                                  working_dir='branch')[0])
 
         rev_id = tree.branch.last_revision()
 
-        self.assertEquals(self.run_bzr(
-            ['cat', 'a', '-r', 'revid:%s' % rev_id])[0],
-            'baz\n')
-
-        os.chdir('..')
-
-        self.assertEquals(self.run_bzr(
-            ['cat', 'branch/a', '-r', 'revno:1:branch'])[0],
-            'foo\n')
+        self.assertEquals(
+            'baz\n', self.run_bzr(['cat', 'a', '-r', 'revid:%s' % rev_id],
+                                  working_dir='branch')[0])
+
+        self.assertEquals('foo\n',
+                          self.run_bzr(['cat', 'branch/a',
+                                        '-r', 'revno:1:branch'])[0])
         self.run_bzr(['cat', 'a'], retcode=3)
-        self.run_bzr(
-                ['cat', 'a', '-r', 'revno:1:branch-that-does-not-exist'],
-                retcode=3)
+        self.run_bzr(['cat', 'a', '-r', 'revno:1:branch-that-does-not-exist'],
+                     retcode=3)
 
     def test_cat_different_id(self):
         """'cat' works with old and new files"""
@@ -138,10 +136,9 @@
         wt.add('README')
         wt.commit('Making sure there is a basis_tree available')
         wt = self.make_branch_and_tree('b')
-        os.chdir('b')
 
-        out, err = self.run_bzr(
-            ['cat', '-r', 'branch:../a', 'README'])
+        out, err = self.run_bzr(['cat', '-r', 'branch:../a', 'README'],
+                                working_dir='b')
         self.assertEqual('contents of a/README\n', out)
 
     def test_cat_filters(self):

=== modified file 'bzrlib/tests/blackbox/test_checkout.py'
--- bzrlib/tests/blackbox/test_checkout.py	2011-12-14 21:57:37 +0000
+++ bzrlib/tests/blackbox/test_checkout.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -133,12 +133,11 @@
     def test_checkout_in_branch_with_r(self):
         branch = _mod_branch.Branch.open('branch')
         branch.bzrdir.destroy_workingtree()
-        os.chdir('branch')
-        self.run_bzr('checkout -r 1')
-        tree = workingtree.WorkingTree.open('.')
+        self.run_bzr('checkout -r 1', working_dir='branch')
+        tree = workingtree.WorkingTree.open('branch')
         self.assertEqual('1', tree.last_revision())
         branch.bzrdir.destroy_workingtree()
-        self.run_bzr('checkout -r 0')
+        self.run_bzr('checkout -r 0', working_dir='branch')
         self.assertEqual('null:', tree.last_revision())
 
     def test_checkout_files_from(self):

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2011-12-30 15:26:18 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2011 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -328,11 +328,10 @@
         finally:
             other_tree.unlock()
         this_tree.merge_from_branch(other_tree.branch)
-        os.chdir('this')
-        out,err = self.run_bzr('commit -m added')
+        out, err = self.run_bzr('commit -m added', working_dir='this')
         self.assertEqual('', out)
         self.assertEqual(set([
-            'Committing to: %s/' % osutils.getcwd(),
+            'Committing to: %s/' % osutils.pathjoin(osutils.getcwd(), 'this'),
             'modified filetomodify',
             'added newdir',
             'added newfile',
@@ -472,10 +471,10 @@
         t.add(['file-a', 'dir-a', 'dir-a/file-b'])
         t.commit('Create')
         t.remove(['file-a', 'dir-a/file-b'])
-        os.chdir('dir-a')
-        result = self.run_bzr('commit . -m removed-file-b')[1]
+        result = self.run_bzr('commit . -m removed-file-b',
+                              working_dir='dir-a')[1]
         self.assertNotContainsRe(result, 'file-a')
-        result = self.run_bzr('status')[0]
+        result = self.run_bzr('status', working_dir='dir-a')[0]
         self.assertContainsRe(result, 'removed:\n  file-a')
 
     def test_strict_commit(self):
@@ -485,8 +484,7 @@
         self.build_tree(['tree/a'])
         tree.add('a')
         # A simple change should just work
-        self.run_bzr('commit --strict -m adding-a',
-                     working_dir='tree')
+        self.run_bzr('commit --strict -m adding-a', working_dir='tree')
 
     def test_strict_commit_no_changes(self):
         """commit --strict gives "no changes" if there is nothing to commit"""
@@ -830,30 +828,30 @@
         """Ensure commit error if username is not set.
         """
         self.run_bzr(['init', 'foo'])
-        os.chdir('foo')
-        open('foo.txt', 'w').write('hello')
-        self.run_bzr(['add'])
+        with open('foo/foo.txt', 'w') as f:
+            f.write('hello')
+        self.run_bzr(['add'], working_dir='foo')
         self.overrideEnv('EMAIL', None)
         self.overrideEnv('BZR_EMAIL', None)
         # Also, make sure that it's not inferred from mailname.
         self.overrideAttr(config, '_auto_user_id',
             lambda: (None, None))
-        out, err = self.run_bzr(['commit', '-m', 'initial'], 3)
-        self.assertContainsRe(err, 'Unable to determine your name')
+        self.run_bzr_error(
+            ['Unable to determine your name'],
+            ['commit', '-m', 'initial'], working_dir='foo')
 
     def test_commit_recursive_checkout(self):
         """Ensure that a commit to a recursive checkout fails cleanly.
         """
         self.run_bzr(['init', 'test_branch'])
         self.run_bzr(['checkout', 'test_branch', 'test_checkout'])
-        os.chdir('test_checkout')
-        self.run_bzr(['bind', '.']) # bind to self
-        open('foo.txt', 'w').write('hello')
-        self.run_bzr(['add'])
-        out, err = self.run_bzr(['commit', '-m', 'addedfoo'], 3)
-        self.assertEqual(out, '')
-        self.assertContainsRe(err,
-            'Branch.*test_checkout.*appears to be bound to itself')
+        self.run_bzr(['bind', '.'], working_dir='test_checkout') # bind to self
+        with open('test_checkout/foo.txt', 'w') as f:
+            f.write('hello')
+        self.run_bzr(['add'], working_dir='test_checkout')
+        out, err = self.run_bzr_error(
+            ['Branch.*test_checkout.*appears to be bound to itself'],
+            ['commit', '-m', 'addedfoo'], working_dir='test_checkout')
 
     def test_mv_dirs_non_ascii(self):
         """Move directory with non-ascii name and containing files.

=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2011-01-19 18:44:11 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2011 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,8 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-"""Black-box tests for bzr diff.
-"""
+"""Black-box tests for bzr diff."""
 
 import os
 import re
@@ -288,8 +287,8 @@
         self.example_branch2()
         self.build_tree_contents([('branch1/file1', 'new line')])
         os.mkdir('branch1/dir1')
-        os.chdir('branch1/dir1')
-        output = self.run_bzr('diff -r 1..', retcode=1)
+        output = self.run_bzr('diff -r 1..', retcode=1,
+                              working_dir='branch1/dir1')
         self.assertContainsRe(output[0], '\n\\-original line\n\\+new line\n')
 
     def test_diff_across_rename(self):
@@ -316,8 +315,7 @@
                 return super(BooDiffTree, self).show_diff(specific_files,
                     extra_trees)
 
-        diff_format_registry.register("boo", BooDiffTree, 
-            "Scary diff format")
+        diff_format_registry.register("boo", BooDiffTree, "Scary diff format")
         self.addCleanup(diff_format_registry.remove, "boo")
         self.make_example_branch()
         self.build_tree_contents([('hello', 'hello world!\n')])
@@ -343,7 +341,8 @@
         return tree
 
     def example_branches(self):
-        branch1_tree, branch2_tree = super(TestCheckoutDiff, self).example_branches()
+        branch1_tree, branch2_tree = super(TestCheckoutDiff,
+                                           self).example_branches()
         os.mkdir('checkouts')
         branch1_tree = branch1_tree.branch.create_checkout('checkouts/branch1')
         branch2_tree = branch2_tree.branch.create_checkout('checkouts/branch2')

=== modified file 'bzrlib/tests/blackbox/test_ls.py'
--- bzrlib/tests/blackbox/test_ls.py	2011-12-14 21:57:37 +0000
+++ bzrlib/tests/blackbox/test_ls.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,14 +16,14 @@
 
 """External tests of 'bzr ls'"""
 
-import os
-
-from bzrlib import ignores
-from bzrlib.tests import TestCaseWithTransport
+from bzrlib import (
+    ignores,
+    tests,
+    )
 from bzrlib.tests.matchers import ContainsNoVfsCalls
 
 
-class TestLS(TestCaseWithTransport):
+class TestLS(tests.TestCaseWithTransport):
 
     def setUp(self):
         super(TestLS, self).setUp()
@@ -37,13 +37,13 @@
                                  ('a', 'hello\n'),
                                  ])
 
-    def ls_equals(self, value, args=None, recursive=True):
+    def ls_equals(self, value, args=None, recursive=True, working_dir=None):
         command = 'ls'
         if args is not None:
             command += ' ' + args
         if recursive:
             command += ' -R'
-        out, err = self.run_bzr(command)
+        out, err = self.run_bzr(command, working_dir=working_dir)
         self.assertEqual('', err)
         self.assertEqualDiff(value, out)
 
@@ -127,16 +127,13 @@
                        , '--verbose', recursive=False)
 
         # Check what happens in a sub-directory
-        os.chdir('subdir')
-        self.ls_equals('b\n')
-        self.ls_equals('b\0'
-                  , '--null')
-        self.ls_equals('subdir/b\n'
-                       , '--from-root')
-        self.ls_equals('subdir/b\0'
-                       , '--from-root --null')
-        self.ls_equals('subdir/b\n'
-                       , '--from-root', recursive=False)
+        self.ls_equals('b\n', working_dir='subdir')
+        self.ls_equals('b\0', '--null', working_dir='subdir')
+        self.ls_equals('subdir/b\n', '--from-root', working_dir='subdir')
+        self.ls_equals('subdir/b\0', '--from-root --null',
+                       working_dir='subdir')
+        self.ls_equals('subdir/b\n', '--from-root', recursive=False,
+                       working_dir='subdir')
 
     def test_ls_path(self):
         """If a path is specified, files are listed with that prefix"""
@@ -144,24 +141,23 @@
         self.wt.add(['subdir', 'subdir/b'])
         self.ls_equals('subdir/b\n' ,
                        'subdir')
-        os.chdir('subdir')
         self.ls_equals('../.bzrignore\n'
                        '../a\n'
                        '../subdir/\n'
                        '../subdir/b\n' ,
-                       '..')
+                       '..', working_dir='subdir')
         self.ls_equals('../.bzrignore\0'
                        '../a\0'
                        '../subdir\0'
                        '../subdir/b\0' ,
-                       '.. --null')
+                       '.. --null', working_dir='subdir')
         self.ls_equals('?        ../.bzrignore\n'
                        '?        ../a\n'
                        'V        ../subdir/\n'
                        'V        ../subdir/b\n' ,
-                       '.. --verbose')
+                       '.. --verbose', working_dir='subdir')
         self.run_bzr_error(['cannot specify both --from-root and PATH'],
-                           'ls --from-root ..')
+                           'ls --from-root ..', working_dir='subdir')
 
     def test_ls_revision(self):
         self.wt.add(['a'])
@@ -174,8 +170,7 @@
         self.ls_equals('V        a\n'
                        , '--verbose --revision 1')
 
-        os.chdir('subdir')
-        self.ls_equals('', '--revision 1')
+        self.ls_equals('', '--revision 1', working_dir='subdir')
 
     def test_ls_branch(self):
         """If a branch is specified, files are listed from it"""
@@ -247,7 +242,7 @@
         self.ls_equals('sub/file\n', '-d dir sub')
 
 
-class TestSmartServerLs(TestCaseWithTransport):
+class TestSmartServerLs(tests.TestCaseWithTransport):
 
     def test_simple_ls(self):
         self.setup_smart_server_with_call_log()

=== modified file 'bzrlib/tests/blackbox/test_merge.py'
--- bzrlib/tests/blackbox/test_merge.py	2011-12-27 12:18:36 +0000
+++ bzrlib/tests/blackbox/test_merge.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2011 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -88,45 +88,49 @@
 
         self.build_tree_contents([('a/hello', 'quuux')])
         # We can't merge when there are in-tree changes
-        os.chdir('a')
-        self.run_bzr('merge ../b', retcode=3)
-        a = workingtree.WorkingTree.open('.')
+        self.run_bzr('merge ../b', retcode=3, working_dir='a')
+        a = workingtree.WorkingTree.open('a')
         a_tip = a.commit("Like an epidemic of u's")
-        self.run_bzr('merge ../b -r last:1..last:1 --merge-type blooof',
-                    retcode=3)
-        self.run_bzr('merge ../b -r last:1..last:1 --merge-type merge3')
-        a_tree.revert(backups=False)
-        self.run_bzr('merge ../b -r last:1..last:1 --merge-type weave')
-        a_tree.revert(backups=False)
-        self.run_bzr('merge ../b -r last:1..last:1 --merge-type lca')
-        a_tree.revert(backups=False)
+
+        def run_merge_then_revert(args, retcode=None, working_dir='a'):
+            self.run_bzr(['merge', '../b', '-r', 'last:1..last:1'] + args,
+                         retcode=retcode, working_dir=working_dir)
+            if retcode != 3:
+                a_tree.revert(backups=False)
+
+        run_merge_then_revert(['--merge-type', 'bloof'], retcode=3)
+        run_merge_then_revert(['--merge-type', 'merge3'])
+        run_merge_then_revert(['--merge-type', 'weave'])
+        run_merge_then_revert(['--merge-type', 'lca'])
         self.run_bzr_error(['Show-base is not supported for this merge type'],
                            'merge ../b -r last:1..last:1 --merge-type weave'
-                           ' --show-base')
-        a_tree.revert(backups=False)
-        self.run_bzr('merge ../b -r last:1..last:1 --reprocess')
-        a_tree.revert(backups=False)
-        self.run_bzr('merge ../b -r last:1')
-        self.check_file_contents('goodbye', 'quux')
+                           ' --show-base', working_dir='a')
+        a_tree.revert(backups=False)
+        self.run_bzr('merge ../b -r last:1..last:1 --reprocess',
+                     working_dir='a')
+        a_tree.revert(backups=False)
+        self.run_bzr('merge ../b -r last:1', working_dir='a')
+        self.check_file_contents('a/goodbye', 'quux')
         # Merging a branch pulls its revision into the tree
-        b = branch.Branch.open('../b')
+        b = branch.Branch.open('b')
         b_tip = b.last_revision()
         self.assertTrue(a.branch.repository.has_revision(b_tip))
         self.assertEqual([a_tip, b_tip], a.get_parent_ids())
         a_tree.revert(backups=False)
-        out, err = self.run_bzr('merge -r revno:1:./hello', retcode=3)
+        out, err = self.run_bzr('merge -r revno:1:./hello', retcode=3,
+                                working_dir='a')
         self.assertTrue("Not a branch" in err)
         self.run_bzr('merge -r revno:%d:./..revno:%d:../b'
-                    %(ancestor,b.revno()))
+                    %(ancestor,b.revno()), working_dir='a')
         self.assertEquals(a.get_parent_ids(),
                           [a.branch.last_revision(), b.last_revision()])
-        self.check_file_contents('goodbye', 'quux')
+        self.check_file_contents('a/goodbye', 'quux')
         a_tree.revert(backups=False)
-        self.run_bzr('merge -r revno:%d:../b'%b.revno())
+        self.run_bzr('merge -r revno:%d:../b'%b.revno(), working_dir='a')
         self.assertEquals(a.get_parent_ids(),
                           [a.branch.last_revision(), b.last_revision()])
         a_tip = a.commit('merged')
-        self.run_bzr('merge ../b -r last:1')
+        self.run_bzr('merge ../b -r last:1', working_dir='a')
         self.assertEqual([a_tip], a.get_parent_ids())
 
     def test_merge_defaults_to_reprocess(self):
@@ -211,14 +215,14 @@
             ('b/b.txt', 'hello\nsomething\n'),
             ('b/sub/c.txt', 'hello\nsomething\n')])
         b_tree.commit(message='Modified a.txt')
-        os.chdir('b')
-        self.run_bzr('merge ../a/', retcode=1)
-        self.assertPathExists('sub/a.txt.THIS')
-        self.assertPathExists('sub/a.txt.BASE')
-        os.chdir('../a')
-        self.run_bzr('merge ../b/', retcode=1)
-        self.assertPathExists('sub/a.txt.OTHER')
-        self.assertPathExists('sub/a.txt.BASE')
+
+        self.run_bzr('merge ../a/', retcode=1, working_dir='b')
+        self.assertPathExists('b/sub/a.txt.THIS')
+        self.assertPathExists('b/sub/a.txt.BASE')
+
+        self.run_bzr('merge ../b/', retcode=1, working_dir='a')
+        self.assertPathExists('a/sub/a.txt.OTHER')
+        self.assertPathExists('a/sub/a.txt.BASE')
 
     def test_conflict_leaves_base_this_other_files(self):
         tree, other = self.create_conflicting_branches()
@@ -258,37 +262,37 @@
         branch_b.set_parent(None)
         self.assertEqual(None, branch_b.get_parent())
         # test merge for failure without parent set
-        os.chdir('branch_b')
-        out = self.run_bzr('merge', retcode=3)
+        out = self.run_bzr('merge', retcode=3, working_dir='branch_b')
         self.assertEquals(out,
                 ('','bzr: ERROR: No location specified or remembered\n'))
 
         # test uncommitted changes
-        self.build_tree(['d'])
+        self.build_tree(['branch_b/d'])
         tree_b.add('d')
         self.run_bzr_error(['Working tree ".*" has uncommitted changes'],
-                           'merge')
+                           'merge', working_dir='branch_b')
 
         # merge should now pass and implicitly remember merge location
         tree_b.commit('commit d')
-        out, err = self.run_bzr('merge ../branch_a')
+        out, err = self.run_bzr('merge ../branch_a', working_dir='branch_b')
 
         base = urlutils.local_path_from_url(branch_a.base)
         self.assertEndsWith(err, '+N  b\nAll changes applied successfully.\n')
         self.assertEquals(osutils.abspath(branch_b.get_submit_branch()),
                           osutils.abspath(parent))
         # test implicit --remember when committing new file
-        self.build_tree(['e'])
+        self.build_tree(['branch_b/e'])
         tree_b.add('e')
         tree_b.commit('commit e')
-        out, err = self.run_bzr('merge')
-        self.assertStartsWith(err,
-                          'Merging from remembered submit location %s\n' % (base,))
+        out, err = self.run_bzr('merge', working_dir='branch_b')
+        self.assertStartsWith(
+            err, 'Merging from remembered submit location %s\n' % (base,))
         # re-open tree as external run_bzr modified it
         tree_b = branch_b.bzrdir.open_workingtree()
         tree_b.commit('merge branch_a')
         # test explicit --remember
-        out, err = self.run_bzr('merge ../branch_c --remember')
+        out, err = self.run_bzr('merge ../branch_c --remember',
+                                working_dir='branch_b')
         self.assertEquals(out, '')
         self.assertEquals(err, '+N  c\nAll changes applied successfully.\n')
         self.assertEquals(osutils.abspath(branch_b.get_submit_branch()),
@@ -310,10 +314,8 @@
 
         self.build_tree_contents([('branch_b/a', 'goodbye')])
         tree_b.commit('message')
-        os.chdir('branch_b')
-        self.run_bzr('bundle ../branch_a -o ../bundle')
-        os.chdir('../branch_a')
-        self.run_bzr('merge ../bundle', retcode=1)
+        self.run_bzr('bundle ../branch_a -o ../bundle', working_dir='branch_b')
+        self.run_bzr('merge ../bundle', retcode=1, working_dir='branch_a')
         testament_a = Testament.from_revision(tree_a.branch.repository,
                                               tree_b.get_parent_ids()[0])
         testament_b = Testament.from_revision(tree_b.branch.repository,
@@ -323,10 +325,10 @@
         tree_a.set_conflicts(conflicts.ConflictList())
         tree_a.commit('message')
         # it is legal to attempt to merge an already-merged bundle
-        output = self.run_bzr('merge ../bundle')[1]
+        err = self.run_bzr('merge ../bundle', working_dir='branch_a')[1]
         # but it does nothing
         self.assertFalse(tree_a.changes_from(tree_a.basis_tree()).has_changed())
-        self.assertEqual('Nothing to do.\n', output)
+        self.assertEqual('Nothing to do.\n', err)
 
     def test_merge_uncommitted(self):
         """Check that merge --uncommitted behaves properly"""
@@ -339,7 +341,6 @@
         tree_a.rename_one('file_1', 'file_i')
         tree_a.commit('commit 2')
         tree_a.rename_one('file_2', 'file_ii')
-        ## os.chdir('b')
         self.run_bzr('merge a --uncommitted -d b')
         self.assertPathExists('b/file_1')
         self.assertPathExists('b/file_ii')
@@ -354,10 +355,10 @@
         tree_a.bzrdir.sprout('tree_b')
         self.build_tree(['tree_a/file1', 'tree_a/file2'])
         tree_a.add(['file1', 'file2'])
-        os.chdir('tree_b')
-        self.run_bzr(['merge', '--uncommitted', '../tree_a/file1'])
-        self.assertPathExists('file1')
-        self.assertPathDoesNotExist('file2')
+        self.run_bzr(['merge', '--uncommitted', '../tree_a/file1'],
+                     working_dir='tree_b')
+        self.assertPathExists('tree_b/file1')
+        self.assertPathDoesNotExist('tree_b/file2')
 
     def test_merge_nonexistent_file(self):
         """It should not be possible to merge changes from a file which
@@ -366,9 +367,8 @@
         self.build_tree_contents([('tree_a/file', 'bar\n')])
         tree_a.add(['file'])
         tree_a.commit('commit 1')
-        os.chdir('tree_a')
         self.run_bzr_error(('Path\(s\) do not exist: non/existing',),
-                           ['merge', 'non/existing'])
+                           ['merge', 'non/existing'], working_dir='tree_a')
 
     def pullable_branch(self):
         tree_a = self.make_branch_and_tree('a')
@@ -383,10 +383,9 @@
 
     def test_merge_pull(self):
         self.pullable_branch()
-        os.chdir('a')
-        (out, err) = self.run_bzr('merge --pull ../b')
+        (out, err) = self.run_bzr('merge --pull ../b', working_dir='a')
         self.assertContainsRe(out, 'Now on revision 2\\.')
-        tree_a = workingtree.WorkingTree.open('.')
+        tree_a = workingtree.WorkingTree.open('a')
         self.assertEqual([self.id2], tree_a.get_parent_ids())
 
     def test_merge_pull_preview(self):
@@ -413,14 +412,13 @@
         os.unlink('tree_a/file')
         self.build_tree(['tree_a/file/'])
         tree_a.commit('changed file to directory')
-        os.chdir('tree_b')
-        self.run_bzr('merge ../tree_a')
-        self.assertEqual('directory', osutils.file_kind('file'))
+        self.run_bzr('merge ../tree_a', working_dir='tree_b')
+        self.assertEqual('directory', osutils.file_kind('tree_b/file'))
         tree_b.revert()
-        self.assertEqual('file', osutils.file_kind('file'))
-        self.build_tree_contents([('file', 'content_2')])
+        self.assertEqual('file', osutils.file_kind('tree_b/file'))
+        self.build_tree_contents([('tree_b/file', 'content_2')])
         tree_b.commit('content change')
-        self.run_bzr('merge ../tree_a', retcode=1)
+        self.run_bzr('merge ../tree_a', retcode=1, working_dir='tree_b')
         self.assertEqual(tree_b.conflicts(),
                          [conflicts.ContentsConflict('file',
                                                      file_id='file-id')])

=== modified file 'bzrlib/tests/blackbox/test_merge_directive.py'
--- bzrlib/tests/blackbox/test_merge_directive.py	2012-01-04 17:12:42 +0000
+++ bzrlib/tests/blackbox/test_merge_directive.py	2012-01-05 17:46:44 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2007, 2009-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -234,15 +234,13 @@
         foo = self.make_branch_and_tree('foo')
         foo.commit('rev1')
         bar = self.make_branch_and_tree('bar')
-        os.chdir('foo')
-        self.run_bzr('merge-directive ../bar')
+        self.run_bzr('merge-directive ../bar', working_dir='foo')
 
     def test_no_commits(self):
         foo = self.make_branch_and_tree('foo')
         bar = self.make_branch_and_tree('bar')
-        os.chdir('foo')
         self.run_bzr_error(('No revisions to bundle.', ),
-                            'merge-directive ../bar')
+                            'merge-directive ../bar', working_dir='foo')
 
     def test_encoding_exact(self):
         tree1, tree2 = self.prepare_merge_directive()

=== modified file 'bzrlib/tests/blackbox/test_missing.py'
--- bzrlib/tests/blackbox/test_missing.py	2011-09-16 15:37:58 +0000
+++ bzrlib/tests/blackbox/test_missing.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,13 @@
 
 """Black-box tests for bzr missing."""
 
-import os
-
-from bzrlib import osutils
-
-from bzrlib.branch import Branch
-from bzrlib.tests import TestCaseWithTransport
-
-
-class TestMissing(TestCaseWithTransport):
+from bzrlib import (
+    osutils,
+    tests,
+    )
+
+
+class TestMissing(tests.TestCaseWithTransport):
 
     def assertMessages(self, out, must_have=(), must_not_have=()):
         """Check if commit messages are in or not in the output"""
@@ -49,7 +47,8 @@
         self.assertEqual('', err)
 
     def test_missing(self):
-        missing = "You are missing 1 revision:"
+        missing_one = "You are missing 1 revision:"
+        extra_one = "You have 1 extra revision:"
 
         # create a source branch
         a_tree = self.make_branch_and_tree('a')
@@ -62,6 +61,21 @@
         self.build_tree_contents([('b/a', 'initial\nmore\n')])
         b_tree.commit(message='more')
 
+        def run_missing(args, retcode=1, working_dir=None):
+            out, err = self.run_bzr(['missing'] + args,
+                                    retcode=retcode, working_dir=working_dir)
+            # we do not expect any error output.
+            self.assertEqual('', err)
+            return out.splitlines()
+
+        def run_missing_a(args, retcode=1):
+            return run_missing(['../a'] + args,
+                               retcode=retcode, working_dir='b')
+
+        def run_missing_b(args, retcode=1):
+            return run_missing(['../b'] + args,
+                               retcode=retcode, working_dir='a')
+
         # run missing in a against b
         # this should not require missing to take out a write lock on a
         # or b. So we take a write lock on both to test that at the same
@@ -72,16 +86,13 @@
         a_branch.lock_write()
         b_branch = b_tree.branch
         b_branch.lock_write()
-        os.chdir('a')
-        out,err = self.run_bzr('missing ../b', retcode=1)
-        lines = out.splitlines()
+
+        lines = run_missing_b([])
         # we're missing the extra revision here
-        self.assertEqual(missing, lines[0])
+        self.assertEqual(missing_one, lines[0])
         # and we expect 8 lines of output which we trust at the moment to be
         # good.
         self.assertEqual(8, len(lines))
-        # we do not expect any error output.
-        self.assertEqual('', err)
         # unlock the branches for the rest of the test
         a_branch.unlock()
         b_branch.unlock()
@@ -91,61 +102,60 @@
         a_tree.commit(message='merge')
 
         # compare again, but now we have the 'merge' commit extra
-        lines = self.run_bzr('missing ../b', retcode=1)[0].splitlines()
-        self.assertEqual("You have 1 extra revision:", lines[0])
-        self.assertEqual(8, len(lines))
-        lines2 = self.run_bzr('missing ../b --mine-only', retcode=1)[0]
-        lines2 = lines2.splitlines()
+        lines = run_missing_b([])
+        self.assertEqual(extra_one, lines[0])
+        self.assertLength(8, lines)
+
+        lines2 = run_missing_b(['--mine-only'])
         self.assertEqual(lines, lines2)
-        lines3 = self.run_bzr('missing ../b --theirs-only', retcode=0)[0]
-        self.assertEqualDiff('Other branch has no new revisions.\n', lines3)
+
+        lines3 = run_missing_b(['--theirs-only'], retcode=0)
+        self.assertEqualDiff('Other branch has no new revisions.', lines3[0])
 
         # relative to a, missing the 'merge' commit
-        os.chdir('../b')
-        lines = self.run_bzr('missing ../a', retcode=1)[0].splitlines()
-        self.assertEqual(missing, lines[0])
-        self.assertEqual(8, len(lines))
-        lines2 = self.run_bzr('missing ../a --theirs-only', retcode=1)[0]
-        lines2 = lines2.splitlines()
+        lines = run_missing_a([])
+        self.assertEqual(missing_one, lines[0])
+        self.assertLength(8, lines)
+
+        lines2 = run_missing_a(['--theirs-only'])
         self.assertEqual(lines, lines2)
-        lines3 = self.run_bzr('missing ../a --mine-only', retcode=0)[0]
-        self.assertEqualDiff('This branch has no new revisions.\n', lines3)
-        lines4 = self.run_bzr('missing ../a --short', retcode=1)[0]
-        lines4 = lines4.splitlines()
-        self.assertEqual(4, len(lines4))
-        lines4a = self.run_bzr('missing ../a -S', retcode=1)[0]
-        lines4a = lines4a.splitlines()
+
+        lines3 = run_missing_a(['--mine-only'], retcode=0)
+        self.assertEqualDiff('This branch has no new revisions.', lines3[0])
+
+        lines4 = run_missing_a(['--short'])
+        self.assertLength(4, lines4)
+
+        lines4a = run_missing_a(['-S'])
         self.assertEqual(lines4, lines4a)
-        lines5 = self.run_bzr('missing ../a --line', retcode=1)[0]
-        lines5 = lines5.splitlines()
-        self.assertEqual(2, len(lines5))
-        lines6 = self.run_bzr('missing ../a --reverse', retcode=1)[0]
-        lines6 = lines6.splitlines()
+
+        lines5 = run_missing_a(['--line'])
+        self.assertLength(2, lines5)
+
+        lines6 = run_missing_a(['--reverse'])
         self.assertEqual(lines6, lines)
-        lines7 = self.run_bzr('missing ../a --show-ids', retcode=1)[0]
-        lines7 = lines7.splitlines()
-        self.assertEqual(11, len(lines7))
-        lines8 = self.run_bzr('missing ../a --verbose', retcode=1)[0]
-        lines8 = lines8.splitlines()
+
+        lines7 = run_missing_a(['--show-ids'])
+        self.assertLength(11, lines7)
+
+        lines8 =  run_missing_a(['--verbose'])
         self.assertEqual("modified:", lines8[-2])
         self.assertEqual("  a", lines8[-1])
 
-        os.chdir('../a')
-        self.assertEqualDiff('Other branch has no new revisions.\n',
-                             self.run_bzr('missing ../b --theirs-only')[0])
+        self.assertEqualDiff('Other branch has no new revisions.',
+                             run_missing_b(['--theirs-only'], retcode=0)[0])
 
         # after a pull we're back on track
         b_tree.pull(a_branch)
-        self.assertEqualDiff("Branches are up to date.\n",
-                             self.run_bzr('missing ../b')[0])
-        os.chdir('../b')
-        self.assertEqualDiff('Branches are up to date.\n',
-                             self.run_bzr('missing ../a')[0])
+        self.assertEqualDiff("Branches are up to date.",
+                             run_missing_b([], retcode=0)[0])
+        self.assertEqualDiff('Branches are up to date.',
+                             run_missing_a([], retcode=0)[0])
         # If you supply mine or theirs you only know one side is up to date
-        self.assertEqualDiff('This branch has no new revisions.\n',
-                             self.run_bzr('missing ../a --mine-only')[0])
-        self.assertEqualDiff('Other branch has no new revisions.\n',
-                             self.run_bzr('missing ../a --theirs-only')[0])
+        self.assertEqualDiff('This branch has no new revisions.',
+                             run_missing_a(['--mine-only'], retcode=0)[0])
+        self.assertEqualDiff('Other branch has no new revisions.',
+                              run_missing_a(['--theirs-only'], retcode=0)[0])
 
     def test_missing_filtered(self):
         # create a source branch
@@ -160,24 +170,27 @@
             a_tree.commit(message='a%d' % i)
             b_tree.commit(message='b%d' % i)
 
-        os.chdir('a')
         # local
-        out,err = self.run_bzr('missing ../b --my-revision 3', retcode=1)
+        out,err = self.run_bzr('missing ../b --my-revision 3',
+                               retcode=1, working_dir='a')
         self.assertMessages(out, ('a3', 'b2', 'b3', 'b4', 'b5'), ('a2', 'a4'))
 
-        out,err = self.run_bzr('missing ../b --my-revision 3..4', retcode=1)
+        out,err = self.run_bzr('missing ../b --my-revision 3..4',
+                               retcode=1, working_dir='a')
         self.assertMessages(out, ('a3', 'a4'), ('a2', 'a5'))
 
         #remote
-        out,err = self.run_bzr('missing ../b -r 3', retcode=1)
+        out,err = self.run_bzr('missing ../b -r 3',
+                               retcode=1, working_dir='a')
         self.assertMessages(out, ('a2', 'a3', 'a4', 'a5', 'b3'), ('b2', 'b4'))
 
-        out,err = self.run_bzr('missing ../b -r 3..4', retcode=1)
+        out,err = self.run_bzr('missing ../b -r 3..4',
+                               retcode=1, working_dir='a')
         self.assertMessages(out, ('b3', 'b4'), ('b2', 'b5'))
 
         #both
         out,err = self.run_bzr('missing ../b --my-revision 3..4 -r 3..4',
-            retcode=1)
+                               retcode=1, working_dir='a')
         self.assertMessages(out, ('a3', 'a4', 'b3', 'b4'),
             ('a2', 'a5', 'b2', 'b5'))
 
@@ -191,14 +204,13 @@
         wt.add('foo')
         wt.commit('initial')
 
-        os.chdir('a')
-        location = osutils.getcwd() + '/'
+        location = osutils.getcwd() + '/a/'
 
         # clone
-        b.bzrdir.sprout('../b')
+        b.bzrdir.sprout('b')
 
         # check last location
-        lines, err = self.run_bzr('missing', working_dir='../b')
+        lines, err = self.run_bzr('missing', working_dir='b')
         self.assertEquals('Using saved parent location: %s\n'
                           'Branches are up to date.\n' % location,
                           lines)
@@ -219,7 +231,6 @@
         b_tree.commit(message='more')
 
         out2, err2 = self.run_bzr('missing --directory a b', retcode=1)
-        os.chdir('a')
-        out1, err1 = self.run_bzr('missing ../b', retcode=1)
+        out1, err1 = self.run_bzr('missing ../b', retcode=1, working_dir='a')
         self.assertEqualDiff(out1, out2)
         self.assertEqualDiff(err1, err2)

=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2011-12-06 12:36:26 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -120,13 +120,10 @@
         tree = self.make_branch_and_tree('.')
         tree.add(['sub1', 'sub1/sub2', 'sub1/hello.txt'])
 
-        os.chdir('sub1/sub2')
-        self.run_bzr('mv ../hello.txt .')
-        self.assertPathExists('./hello.txt')
+        self.run_bzr('mv ../hello.txt .', working_dir='sub1/sub2')
+        self.assertPathExists('sub1/sub2/hello.txt')
 
-        os.chdir('..')
-        self.run_bzr('mv sub2/hello.txt .')
-        os.chdir('..')
+        self.run_bzr('mv sub2/hello.txt .', working_dir='sub1')
         self.assertMoved('sub1/sub2/hello.txt','sub1/hello.txt')
 
     def test_mv_change_case_file(self):

=== modified file 'bzrlib/tests/blackbox/test_nick.py'
--- bzrlib/tests/blackbox/test_nick.py	2010-06-23 08:19:28 +0000
+++ bzrlib/tests/blackbox/test_nick.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2010, 2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,74 +16,75 @@
 
 """Black-box tests for bzr nick."""
 
-import os
-
 import bzrlib
-from bzrlib import osutils
-from bzrlib.tests import TestCaseWithTransport
-
-
-class TestNick(TestCaseWithTransport):
+from bzrlib import (
+    branch,
+    osutils,
+    tests,
+    )
+
+
+class TestNick(tests.TestCaseWithTransport):
+
+    def assertNick(self, expected, working_dir='.', explicit=None,
+                   directory=None):
+        cmd = ['nick']
+        if directory is not None:
+            cmd.extend(['--directory', directory])
+        # The nick command outputs the nick on a single line
+        actual = self.run_bzr(cmd, working_dir=working_dir)[0][:-1]
+        self.assertEquals(expected, actual)
+        if explicit is not None:
+            br = branch.Branch.open(working_dir)
+            conf = br.get_config()
+            self.assertEquals(explicit, conf.has_explicit_nickname())
+            if explicit:
+                self.assertEquals(expected, conf._get_explicit_nickname())
 
     def test_nick_command(self):
         """bzr nick for viewing, setting nicknames"""
         self.make_branch_and_tree('me.dev')
-        os.chdir('me.dev')
-        nick = self.run_bzr('nick')[0]
-        self.assertEqual('me.dev\n', nick)
+        self.assertNick('me.dev', working_dir='me.dev')
         # set the nickname
-        self.run_bzr("nick moo")
-        nick = self.run_bzr('nick')[0]
-        self.assertEqual('moo\n', nick)
+        self.run_bzr("nick moo", working_dir='me.dev')
+        self.assertNick('moo', working_dir='me.dev')
 
     def test_autonick_urlencoded(self):
         # https://bugs.launchpad.net/bzr/+bug/66857 -- nick was printed
         # urlencoded but shouldn't be
         self.make_branch_and_tree('!repo')
-        os.chdir('!repo')
-        nick = self.run_bzr('nick')[0]
-        self.assertEqual('!repo\n', nick)
+        self.assertNick('!repo', working_dir='!repo')
 
     def test_bound_nick(self):
-        """Check that nick works well for checkouts."""
-        base = self.make_branch_and_tree('base')
-        child = self.make_branch_and_tree('child')
-        os.chdir('child')
-        self.assertEqual('child', self.run_bzr('nick')[0][:-1])
-        self.assertEqual(False,
-                         child.branch.get_config().has_explicit_nickname())
-        self.run_bzr('bind ../base')
-        self.assertEqual(base.branch.nick, self.run_bzr('nick')[0][:-1])
-        self.assertEqual(False,
-                         child.branch.get_config().has_explicit_nickname())
-
-        self.run_bzr('unbind')
-        self.run_bzr("nick explicit_nick")
-        self.assertEqual("explicit_nick", self.run_bzr('nick')[0][:-1])
-        self.assertEqual("explicit_nick",
-                         child.branch.get_config()._get_explicit_nickname())
-        self.run_bzr('bind ../base')
-        self.assertEqual(base.branch.nick, self.run_bzr('nick')[0][:-1])
-        self.assertEqual(base.branch.nick,
-                         child.branch.get_config()._get_explicit_nickname())
+        """Bind should not update implicit nick."""
+        base = self.make_branch_and_tree('base')
+        child = self.make_branch_and_tree('child')
+        self.assertNick('child', working_dir='child', explicit=False)
+
+        self.run_bzr('bind ../base', working_dir='child')
+        self.assertNick(base.branch.nick, working_dir='child', explicit=False)
+
+    def test_bound_nick_explicit(self):
+        """Bind should update explicit nick."""
+        base = self.make_branch_and_tree('base')
+        child = self.make_branch_and_tree('child')
+        self.run_bzr("nick explicit_nick", working_dir='child')
+        self.assertNick('explicit_nick', working_dir='child', explicit=True)
+        self.run_bzr('bind ../base', working_dir='child')
+        self.assertNick(base.branch.nick, working_dir='child', explicit=True)
 
     def test_boundless_nick(self):
         """Nick defaults to implicit local nick when bound branch is AWOL"""
         base = self.make_branch_and_tree('base')
         child = self.make_branch_and_tree('child')
-        os.chdir('child')
-        self.run_bzr('bind ../base')
-        self.assertEqual(base.branch.nick, self.run_bzr('nick')[0][:-1])
-        self.assertEqual(False,
-                         child.branch.get_config().has_explicit_nickname())
-        osutils.rmtree('../base')
-        self.assertEqual('child', self.run_bzr('nick')[0][:-1])
+        self.run_bzr('bind ../base', working_dir='child')
+        self.assertNick(base.branch.nick, working_dir='child', explicit=False)
+        osutils.rmtree('base')
+        self.assertNick('child', working_dir='child', explicit=False)
 
     def test_nick_directory(self):
         """Test --directory option"""
         self.make_branch_and_tree('me.dev')
-        nick = self.run_bzr(['nick', '--directory=me.dev'])[0]
-        self.assertEqual('me.dev\n', nick)
+        self.assertNick('me.dev', directory='me.dev')
         self.run_bzr(['nick', '-d', 'me.dev', 'moo'])
-        nick = self.run_bzr(['nick', '--directory', 'me.dev'])[0]
-        self.assertEqual('moo\n', nick)
+        self.assertNick('moo', directory='me.dev')

=== modified file 'bzrlib/tests/blackbox/test_pack.py'
--- bzrlib/tests/blackbox/test_pack.py	2011-12-14 21:57:37 +0000
+++ bzrlib/tests/blackbox/test_pack.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2007, 2009-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@
         for i in range(total_lines):
             text += line_prefix + str(i+1) + "\n"
 
-        open(path, 'w').write(text)
+        with open(path, 'w') as f:
+            f.write(text)
         if versioned:
             self.run_bzr(['add', path])
             self.run_bzr(['ci', '-m', '"' + path + '"'])
@@ -69,10 +70,8 @@
     def test_pack_clean_obsolete_packs(self):
         """Ensure --clean-obsolete-packs removes obsolete pack files
         """
-        wd = 'foobar0'
-        wt = self.make_branch_and_tree(wd)
-        transport = wt.branch.repository.bzrdir.transport
-        os.chdir(wd)
+        wt = self.make_branch_and_tree('.')
+        t = wt.branch.repository.bzrdir.transport
 
         # do multiple commits to ensure that obsolete packs are created
         # by 'bzr pack'
@@ -82,7 +81,7 @@
 
         out, err = self.run_bzr(['pack', '--clean-obsolete-packs'])
 
-        pack_names = transport.list_dir('repository/obsolete_packs')
+        pack_names = t.list_dir('repository/obsolete_packs')
         self.assertTrue(len(pack_names) == 0)
 
 

=== modified file 'bzrlib/tests/blackbox/test_pull.py'
--- bzrlib/tests/blackbox/test_pull.py	2012-01-04 17:12:42 +0000
+++ bzrlib/tests/blackbox/test_pull.py	2012-01-05 17:46:44 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,21 +21,21 @@
 import sys
 
 from bzrlib import (
+    branch,
     debug,
+    osutils,
     remote,
     tests,
+    uncommit,
     urlutils,
+    workingtree,
     )
 
-from bzrlib.branch import Branch
 from bzrlib.directory_service import directories
-from bzrlib.osutils import pathjoin
 from bzrlib.tests import (
     fixtures,
     script,
     )
-from bzrlib.uncommit import uncommit
-from bzrlib.workingtree import WorkingTree
 
 
 class TestPull(tests.TestCaseWithTransport):
@@ -43,8 +43,8 @@
     def example_branch(self, path='.'):
         tree = self.make_branch_and_tree(path)
         self.build_tree_contents([
-            (pathjoin(path, 'hello'),   'foo'),
-            (pathjoin(path, 'goodbye'), 'baz')])
+            (osutils.pathjoin(path, 'hello'),   'foo'),
+            (osutils.pathjoin(path, 'goodbye'), 'baz')])
         tree.add('hello')
         tree.commit(message='setup')
         tree.add('goodbye')
@@ -55,63 +55,53 @@
         """Pull changes from one branch to another."""
         a_tree = self.example_branch('a')
         base_rev = a_tree.branch.last_revision()
-        os.chdir('a')
-        self.run_bzr('pull', retcode=3)
-        self.run_bzr('missing', retcode=3)
-        self.run_bzr('missing .')
-        self.run_bzr('missing')
+        self.run_bzr('pull', retcode=3, working_dir='a')
+        self.run_bzr('missing', retcode=3, working_dir='a')
+        self.run_bzr('missing .', working_dir='a')
+        self.run_bzr('missing', working_dir='a')
         # this will work on windows because we check for the same branch
         # in pull - if it fails, it is a regression
-        self.run_bzr('pull')
-        self.run_bzr('pull /', retcode=3)
+        self.run_bzr('pull', working_dir='a')
+        self.run_bzr('pull /', retcode=3, working_dir='a')
         if sys.platform not in ('win32', 'cygwin'):
-            self.run_bzr('pull')
+            self.run_bzr('pull', working_dir='a')
 
-        os.chdir('..')
         b_tree = a_tree.bzrdir.sprout('b').open_workingtree()
-        os.chdir('b')
-        self.run_bzr('pull')
-        os.mkdir('subdir')
+        self.run_bzr('pull', working_dir='b')
+        os.mkdir('b/subdir')
         b_tree.add('subdir')
         new_rev = b_tree.commit(message='blah', allow_pointless=True)
 
-        os.chdir('..')
-        a = Branch.open('a')
-        b = Branch.open('b')
+        a = branch.Branch.open('a')
+        b = branch.Branch.open('b')
         self.assertEqual(a.last_revision(), base_rev)
         self.assertEqual(b.last_revision(), new_rev)
 
-        os.chdir('a')
-        self.run_bzr('pull ../b')
+        self.run_bzr('pull ../b', working_dir='a')
         self.assertEqual(a.last_revision(), b.last_revision())
         a_tree.commit(message='blah2', allow_pointless=True)
         b_tree.commit(message='blah3', allow_pointless=True)
         # no overwrite
-        os.chdir('../b')
-        self.run_bzr('pull ../a', retcode=3)
-        os.chdir('..')
+        self.run_bzr('pull ../a', retcode=3, working_dir='b')
         b_tree.bzrdir.sprout('overwriteme')
-        os.chdir('overwriteme')
-        self.run_bzr('pull --overwrite ../a')
-        overwritten = Branch.open('.')
+        self.run_bzr('pull --overwrite ../a', working_dir='overwriteme')
+        overwritten = branch.Branch.open('overwriteme')
         self.assertEqual(overwritten.last_revision(),
                          a.last_revision())
         a_tree.merge_from_branch(b_tree.branch)
         a_tree.commit(message="blah4", allow_pointless=True)
-        os.chdir('../b/subdir')
-        self.run_bzr('pull ../../a')
+
+        self.run_bzr('pull ../../a', working_dir='b/subdir')
         self.assertEqual(a.last_revision(), b.last_revision())
-        sub_tree = WorkingTree.open_containing('.')[0]
+        sub_tree = workingtree.WorkingTree.open_containing('b/subdir')[0]
         sub_tree.commit(message="blah5", allow_pointless=True)
         sub_tree.commit(message="blah6", allow_pointless=True)
-        os.chdir('..')
-        self.run_bzr('pull ../a')
-        os.chdir('../a')
+        self.run_bzr('pull ../a', working_dir='b')
         a_tree.commit(message="blah7", allow_pointless=True)
         a_tree.merge_from_branch(b_tree.branch)
         a_tree.commit(message="blah8", allow_pointless=True)
-        self.run_bzr('pull ../b')
-        self.run_bzr('pull ../b')
+        self.run_bzr('pull ../b', working_dir='a')
+        self.run_bzr('pull ../b', working_dir='a')
 
     def test_pull_dash_d(self):
         self.example_branch('a')
@@ -137,15 +127,14 @@
 
         b_tree = a_tree.bzrdir.sprout('b',
                    revision_id=a_tree.branch.get_rev_id(1)).open_workingtree()
-        os.chdir('b')
-        self.run_bzr('pull -r 2')
-        a = Branch.open('../a')
-        b = Branch.open('.')
+        self.run_bzr('pull -r 2', working_dir='b')
+        a = branch.Branch.open('a')
+        b = branch.Branch.open('b')
         self.assertEqual(a.revno(),4)
         self.assertEqual(b.revno(),2)
-        self.run_bzr('pull -r 3')
+        self.run_bzr('pull -r 3', working_dir='b')
         self.assertEqual(b.revno(),3)
-        self.run_bzr('pull -r 4')
+        self.run_bzr('pull -r 4', working_dir='b')
         self.assertEqual(a.last_revision(), b.last_revision())
 
     def test_pull_tags(self):
@@ -189,8 +178,7 @@
 
         self.assertEqual(b_tree.branch.last_revision_info()[0], 2)
 
-        os.chdir('b')
-        self.run_bzr('pull --overwrite ../a')
+        self.run_bzr('pull --overwrite ../a', working_dir='b')
         (last_revinfo_b) = b_tree.branch.last_revision_info()
         self.assertEqual(last_revinfo_b[0], 3)
         self.assertEqual(last_revinfo_b[1], a_tree.branch.last_revision())
@@ -226,15 +214,14 @@
 
         # With convergence, we could just pull over the
         # new change, but with --overwrite, we want to switch our history
-        os.chdir('b')
-        self.run_bzr('pull --overwrite ../a')
+        self.run_bzr('pull --overwrite ../a', working_dir='b')
         rev_info_b = b_tree.branch.last_revision_info()
         self.assertEqual(rev_info_b[0], 4)
         self.assertEqual(rev_info_b, rev_info_a)
 
     def test_pull_remember(self):
         """Pull changes from one branch to another and test parent location."""
-        transport = self.get_transport()
+        t = self.get_transport()
         tree_a = self.make_branch_and_tree('branch_a')
         branch_a = tree_a.branch
         self.build_tree(['branch_a/a'])
@@ -252,27 +239,27 @@
         branch_b.set_parent(None)
         self.assertEqual(None, branch_b.get_parent())
         # test pull for failure without parent set
-        os.chdir('branch_b')
-        out = self.run_bzr('pull', retcode=3)
+        out = self.run_bzr('pull', retcode=3, working_dir='branch_b')
         self.assertEqual(out,
                 ('','bzr: ERROR: No pull location known or specified.\n'))
         # test implicit --remember when no parent set, this pull conflicts
-        self.build_tree(['d'])
+        self.build_tree(['branch_b/d'])
         tree_b.add('d')
         tree_b.commit('commit d')
-        out = self.run_bzr('pull ../branch_a', retcode=3)
+        out = self.run_bzr('pull ../branch_a', retcode=3,
+                           working_dir='branch_b')
         self.assertEqual(out,
                 ('','bzr: ERROR: These branches have diverged.'
                     ' Use the missing command to see how.\n'
                     'Use the merge command to reconcile them.\n'))
         self.assertEqual(branch_b.get_parent(), parent)
         # test implicit --remember after resolving previous failure
-        uncommit(branch=branch_b, tree=tree_b)
-        transport.delete('branch_b/d')
-        self.run_bzr('pull')
+        uncommit.uncommit(branch=branch_b, tree=tree_b)
+        t.delete('branch_b/d')
+        self.run_bzr('pull', working_dir='branch_b')
         self.assertEqual(branch_b.get_parent(), parent)
         # test explicit --remember
-        self.run_bzr('pull ../branch_c --remember')
+        self.run_bzr('pull ../branch_c --remember', working_dir='branch_b')
         self.assertEqual(branch_b.get_parent(),
                           branch_c.bzrdir.root_transport.base)
 
@@ -280,26 +267,22 @@
         from bzrlib.testament import Testament
         # Build up 2 trees and prepare for a pull
         tree_a = self.make_branch_and_tree('branch_a')
-        f = open('branch_a/a', 'wb')
-        f.write('hello')
-        f.close()
+        with open('branch_a/a', 'wb') as f:
+            f.write('hello')
         tree_a.add('a')
         tree_a.commit('message')
 
         tree_b = tree_a.bzrdir.sprout('branch_b').open_workingtree()
 
         # Make a change to 'a' that 'b' can pull
-        f = open('branch_a/a', 'wb')
-        f.write('hey there')
-        f.close()
+        with open('branch_a/a', 'wb') as f:
+            f.write('hey there')
         tree_a.commit('message')
 
         # Create the bundle for 'b' to pull
-        os.chdir('branch_a')
-        self.run_bzr('bundle ../branch_b -o ../bundle')
+        self.run_bzr('bundle ../branch_b -o ../bundle', working_dir='branch_a')
 
-        os.chdir('../branch_b')
-        out, err = self.run_bzr('pull ../bundle')
+        out, err = self.run_bzr('pull ../bundle', working_dir='branch_b')
         self.assertEqual(out,
                          'Now on revision 2.\n')
         self.assertEqual(err,
@@ -316,7 +299,7 @@
                              testament_b.as_text())
 
         # it is legal to attempt to pull an already-merged bundle
-        out, err = self.run_bzr('pull ../bundle')
+        out, err = self.run_bzr('pull ../bundle', working_dir='branch_b')
         self.assertEqual(err, '')
         self.assertEqual(out, 'No revisions or tags to pull.\n')
 
@@ -422,7 +405,7 @@
         # upwards without agreement from bzr's network support maintainers.
         self.assertLength(19, self.hpss_calls)
         self.assertLength(1, self.hpss_connections)
-        remote = Branch.open('stacked')
+        remote = branch.Branch.open('stacked')
         self.assertEndsWith(remote.get_stacked_on_url(), '/parent')
 
     def test_pull_cross_format_warning(self):
@@ -492,26 +475,25 @@
         a_tree = self.example_branch('a')
         b_tree = a_tree.bzrdir.sprout('b').open_workingtree()
 
-        f = open(pathjoin('a', 'hello'),'wt')
-        f.write('fee')
-        f.close()
+        with open(osutils.pathjoin('a', 'hello'),'wt') as f:
+            f.write('fee')
         a_tree.commit('fee')
 
-        f = open(pathjoin('b', 'hello'),'wt')
-        f.write('fie')
-        f.close()
+        with open(osutils.pathjoin('b', 'hello'),'wt') as f:
+            f.write('fie')
 
         out,err=self.run_bzr(['pull','-d','b','a','--show-base'])
 
         # check for message here
-        self.assertEqual(err,
-                         ' M  hello\nText conflict in hello\n1 conflicts encountered.\n')
+        self.assertEqual(
+            err,
+            ' M  hello\nText conflict in hello\n1 conflicts encountered.\n')
 
         self.assertEqualDiff('<<<<<<< TREE\n'
                              'fie||||||| BASE-REVISION\n'
                              'foo=======\n'
                              'fee>>>>>>> MERGE-SOURCE\n',
-                             open(pathjoin('b', 'hello')).read())
+                             open(osutils.pathjoin('b', 'hello')).read())
 
     def test_pull_show_base_working_tree_only(self):
         """--show-base only allowed if there's a working tree
@@ -521,8 +503,8 @@
         self.make_branch('from')
         self.make_branch('to')
         out=self.run_bzr(['pull','-d','to','from','--show-base'],retcode=3)
-        self.assertEqual(out,
-                         ('','bzr: ERROR: Need working tree for --show-base.\n'))
+        self.assertEqual(
+            out, ('','bzr: ERROR: Need working tree for --show-base.\n'))
 
     def test_pull_tag_conflicts(self):
         """pulling tags with conflicts will change the exit code"""

=== modified file 'bzrlib/tests/blackbox/test_remerge.py'
--- bzrlib/tests/blackbox/test_remerge.py	2011-05-13 12:51:05 +0000
+++ bzrlib/tests/blackbox/test_remerge.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,98 +24,102 @@
 class TestRemerge(TestCaseWithTransport):
 
     def make_file(self, name, contents):
-        f = open(name, 'wb')
-        try:
+        with open(name, 'wb') as f:
             f.write(contents)
-        finally:
-            f.close()
 
     def create_conflicts(self):
         """Create a conflicted tree"""
         os.mkdir('base')
-        os.chdir('base')
-        self.make_file('hello', "hi world")
-        self.make_file('answer', "42")
-        self.run_bzr('init')
-        self.run_bzr('add')
-        self.run_bzr('commit -m base')
-        self.run_bzr('branch . ../other')
-        self.run_bzr('branch . ../this')
-        os.chdir('../other')
-        self.make_file('hello', "Hello.")
-        self.make_file('answer', "Is anyone there?")
-        self.run_bzr('commit -m other')
-        os.chdir('../this')
-        self.make_file('hello', "Hello, world")
-        self.run_bzr('mv answer question')
-        self.make_file('question', "What do you get when you multiply six"
-                                   "times nine?")
-        self.run_bzr('commit -m this')
+        self.make_file('base/hello', "hi world")
+        self.make_file('base/answer', "42")
+        self.run_bzr('init', working_dir='base')
+        self.run_bzr('add', working_dir='base')
+        self.run_bzr('commit -m base', working_dir='base')
+        self.run_bzr('branch base other')
+        self.run_bzr('branch base this')
+        self.make_file('other/hello', "Hello.")
+        self.make_file('other/answer', "Is anyone there?")
+        self.run_bzr('commit -m other', working_dir='other')
+        self.make_file('this/hello', "Hello, world")
+        self.run_bzr('mv answer question', working_dir='this')
+        self.make_file('this/question',
+                       "What do you get when you multiply sixtimes nine?")
+        self.run_bzr('commit -m this', working_dir='this')
 
     def test_remerge(self):
         """Remerge command works as expected"""
         self.create_conflicts()
-        self.run_bzr('merge ../other --show-base', retcode=1)
-        conflict_text = open('hello').read()
+        self.run_bzr('merge ../other --show-base',
+                     retcode=1, working_dir='this')
+        conflict_text = open('this/hello').read()
         self.assertTrue('|||||||' in conflict_text)
         self.assertTrue('hi world' in conflict_text)
 
-        self.run_bzr_error(['conflicts encountered'], 'remerge', retcode=1)
-        conflict_text = open('hello').read()
+        self.run_bzr_error(['conflicts encountered'], 'remerge',
+                           retcode=1, working_dir='this')
+        with open('this/hello') as f:
+            conflict_text = f.read()
         self.assertFalse('|||||||' in conflict_text)
         self.assertFalse('hi world' in conflict_text)
 
-        os.unlink('hello.OTHER')
-        os.unlink('question.OTHER')
+        os.unlink('this/hello.OTHER')
+        os.unlink('this/question.OTHER')
 
         self.run_bzr_error(['jello is not versioned'],
-                     'remerge jello --merge-type weave')
+                     'remerge jello --merge-type weave', working_dir='this')
         self.run_bzr_error(['conflicts encountered'],
                            'remerge hello --merge-type weave',
-                           retcode=1)
-
-        self.assertPathExists('hello.OTHER')
-        self.assertPathDoesNotExist('question.OTHER')
-
-        file_id = self.run_bzr('file-id hello')[0]
+                           retcode=1, working_dir='this')
+
+        self.assertPathExists('this/hello.OTHER')
+        self.assertPathDoesNotExist('this/question.OTHER')
+
+        file_id = self.run_bzr('file-id hello', working_dir='this')[0]
         self.run_bzr_error(['hello.THIS is not versioned'],
-                           'file-id hello.THIS')
+                           'file-id hello.THIS', working_dir='this')
 
         self.run_bzr_error(['conflicts encountered'],
-                           'remerge --merge-type weave', retcode=1)
+                           'remerge --merge-type weave',
+                           retcode=1, working_dir='this')
 
-        self.assertPathExists('hello.OTHER')
-        self.assertTrue('hello.BASE')
+        self.assertPathExists('this/hello.OTHER')
+        self.assertTrue('this/hello.BASE')
+        with open('this/hello') as f:
+            conflict_text = f.read()
         self.assertFalse('|||||||' in conflict_text)
         self.assertFalse('hi world' in conflict_text)
 
         self.run_bzr_error(['Showing base is not supported.*Weave'],
-                           'remerge . --merge-type weave --show-base')
-        self.run_bzr_error(['Can\'t reprocess and show base'],
-                           'remerge . --show-base --reprocess')
+                           'remerge . --merge-type weave --show-base',
+                           working_dir='this')
+        self.run_bzr_error(["Can't reprocess and show base"],
+                           'remerge . --show-base --reprocess',
+                           working_dir='this')
         self.run_bzr_error(['conflicts encountered'],
                            'remerge . --merge-type weave --reprocess',
-                           retcode=1)
+                           retcode=1, working_dir='this')
         self.run_bzr_error(['conflicts encountered'],
                            'remerge hello --show-base',
-                           retcode=1)
+                           retcode=1, working_dir='this')
         self.run_bzr_error(['conflicts encountered'],
-                           'remerge hello --reprocess', retcode=1)
+                           'remerge hello --reprocess',
+                           retcode=1, working_dir='this')
 
-        self.run_bzr('resolve --all')
-        self.run_bzr('commit -m done')
+        self.run_bzr('resolve --all', working_dir='this')
+        self.run_bzr('commit -m done', working_dir='this')
 
         self.run_bzr_error(['remerge only works after normal merges',
                             'Not cherrypicking or multi-merges'],
-                           'remerge')
+                           'remerge', working_dir='this')
 
     def test_conflicts(self):
         self.create_conflicts()
-        self.run_bzr('merge ../other', retcode=1)
-        wt = WorkingTree.open('.')
-        self.assertEqual(2, len(wt.conflicts()))
-        self.run_bzr('remerge', retcode=1)
-        wt = WorkingTree.open('.')
-        self.assertEqual(2, len(wt.conflicts()))
-        self.run_bzr('remerge hello', retcode=1)
+        self.run_bzr('merge ../other', retcode=1, working_dir='this')
+        wt = WorkingTree.open('this')
+        self.assertEqual(2, len(wt.conflicts()))
+        self.run_bzr('remerge', retcode=1, working_dir='this')
+        wt = WorkingTree.open('this')
+        self.assertEqual(2, len(wt.conflicts()))
+        self.run_bzr('remerge hello', retcode=1, working_dir='this')
+        wt = WorkingTree.open('this')
         self.assertEqual(2, len(wt.conflicts()))

=== modified file 'bzrlib/tests/blackbox/test_remove_tree.py'
--- bzrlib/tests/blackbox/test_remove_tree.py	2011-05-13 12:51:05 +0000
+++ bzrlib/tests/blackbox/test_remove_tree.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,9 +36,8 @@
     # Success modes
 
     def test_remove_tree_original_branch(self):
-        os.chdir('branch1')
-        self.run_bzr('remove-tree')
-        self.assertPathDoesNotExist('foo')
+        self.run_bzr('remove-tree', working_dir='branch1')
+        self.assertPathDoesNotExist('branch1/foo')
 
     def test_remove_tree_original_branch_explicit(self):
         self.run_bzr('remove-tree branch1')
@@ -53,9 +52,8 @@
     def test_remove_tree_sprouted_branch(self):
         self.tree.bzrdir.sprout('branch2')
         self.assertPathExists('branch2/foo')
-        os.chdir('branch2')
-        self.run_bzr('remove-tree')
-        self.assertPathDoesNotExist('foo')
+        self.run_bzr('remove-tree', working_dir='branch2')
+        self.assertPathDoesNotExist('branch2/foo')
 
     def test_remove_tree_sprouted_branch_explicit(self):
         self.tree.bzrdir.sprout('branch2')
@@ -66,10 +64,8 @@
     def test_remove_tree_checkout(self):
         self.tree.branch.create_checkout('branch2', lightweight=False)
         self.assertPathExists('branch2/foo')
-        os.chdir('branch2')
-        self.run_bzr('remove-tree')
-        self.assertPathDoesNotExist('foo')
-        os.chdir('..')
+        self.run_bzr('remove-tree', working_dir='branch2')
+        self.assertPathDoesNotExist('branch2/foo')
         self.assertPathExists('branch1/foo')
 
     def test_remove_tree_checkout_explicit(self):
@@ -84,12 +80,10 @@
     def test_remove_tree_lightweight_checkout(self):
         self.tree.branch.create_checkout('branch2', lightweight=True)
         self.assertPathExists('branch2/foo')
-        os.chdir('branch2')
         output = self.run_bzr_error(
             ["You cannot remove the working tree from a lightweight checkout"],
-            'remove-tree', retcode=3)
-        self.assertPathExists('foo')
-        os.chdir('..')
+            'remove-tree', retcode=3, working_dir='branch2')
+        self.assertPathExists('branch2/foo')
         self.assertPathExists('branch1/foo')
 
     def test_remove_tree_lightweight_checkout_explicit(self):
@@ -103,9 +97,8 @@
 
     def test_remove_tree_empty_dir(self):
         os.mkdir('branch2')
-        os.chdir('branch2')
-        output = self.run_bzr_error(["Not a branch"],
-                                    'remove-tree', retcode=3)
+        output = self.run_bzr_error(
+            ["Not a branch"], 'remove-tree', retcode=3, working_dir='branch2')
 
     def test_remove_tree_repeatedly(self):
         self.run_bzr('remove-tree branch1')

=== modified file 'bzrlib/tests/blackbox/test_revision_history.py'
--- bzrlib/tests/blackbox/test_revision_history.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_revision_history.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,51 +14,53 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import os
-from bzrlib.tests import TestCaseWithTransport
-from bzrlib.branch import Branch
-
-
-class TestRevisionHistory(TestCaseWithTransport):
+from bzrlib import (
+    branch,
+    tests,
+    )
+
+
+class TestRevisionHistory(tests.TestCaseWithTransport):
 
     def _build_branch(self):
         # setup a standalone branch with three commits
         tree = self.make_branch_and_tree('test')
-        open('test/foo', 'wb').write('1111\n')
+        with open('test/foo', 'wb') as f:
+            f.write('1111\n')
         tree.add('foo')
         tree.commit('added foo',rev_id='revision_1')
-        open('test/foo', 'wb').write('2222\n')
+        with open('test/foo', 'wb')as f:
+            f.write('2222\n')
         tree.commit('updated foo',rev_id='revision_2')
-        open('test/foo', 'wb').write('3333\n')
+        with open('test/foo', 'wb')as f:
+            f.write('3333\n')
         tree.commit('updated foo again',rev_id='revision_3')
         return tree
 
-    def _check_revision_history(self, location=''):
-        rh = self.run_bzr(['revision-history', location])[0]
+    def _check_revision_history(self, location='', working_dir=None):
+        rh = self.run_bzr(['revision-history', location],
+                          working_dir=working_dir)[0]
         self.assertEqual(rh, 'revision_1\nrevision_2\nrevision_3\n')
 
     def test_revision_history(self):
-        """Tests 'revision_history' command"""
+        """No location"""
         self._build_branch()
-        os.chdir('test')
-        self._check_revision_history()
+        self._check_revision_history(working_dir='test')
 
     def test_revision_history_with_location(self):
-        """Tests 'revision_history' command with a specified location."""
+        """With a specified location."""
         self._build_branch()
         self._check_revision_history('test')
 
     def test_revision_history_with_repo_branch(self):
-        """Tests 'revision_history' command with a location that is a
-        repository branch."""
+        """With a repository branch location."""
         self._build_branch()
         self.run_bzr('init-repo repo')
         self.run_bzr('branch test repo/test')
         self._check_revision_history('repo/test')
 
     def test_revision_history_with_checkout(self):
-        """Tests 'revision_history' command with a location that is a
-        checkout of a repository branch."""
+        """With a repository branch checkout location."""
         self._build_branch()
         self.run_bzr('init-repo repo')
         self.run_bzr('branch test repo/test')
@@ -66,8 +68,7 @@
         self._check_revision_history('test-checkout')
 
     def test_revision_history_with_lightweight_checkout(self):
-        """Tests 'revision_history' command with a location that is a
-        lightweight checkout of a repository branch."""
+        """With a repository branch lightweight checkout location."""
         self._build_branch()
         self.run_bzr('init-repo repo')
         self.run_bzr('branch test repo/test')

=== modified file 'bzrlib/tests/blackbox/test_versioning.py'
--- bzrlib/tests/blackbox/test_versioning.py	2011-11-24 17:34:23 +0000
+++ bzrlib/tests/blackbox/test_versioning.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -67,11 +67,9 @@
         self.run_bzr(['mkdir', 'dir'])
         self.assert_(os.path.isdir('dir'))
 
-        os.chdir('dir')
         self.log('Run mkdir in subdir')
-        self.run_bzr(['mkdir', 'subdir'])
-        self.assert_(os.path.isdir('subdir'))
-        os.chdir('..')
+        self.run_bzr(['mkdir', 'subdir'], working_dir='dir')
+        self.assert_(os.path.isdir('dir/subdir'))
 
         wt = WorkingTree.open('.')
 
@@ -156,9 +154,9 @@
         self.assertEqual(get_text_by_path(new, 'a/one'), 'new contents')
         new.unlock()
 
-        os.chdir('a')
         # commit from here should do nothing
-        self.run_bzr(['commit', '.', '-m', 'commit subdir only', '--unchanged'])
+        self.run_bzr(['commit', '.', '-m', 'commit subdir only', '--unchanged'],
+                     working_dir='a')
         v3 = b.repository.revision_tree(b.get_rev_id(3))
         v3.lock_read()
         self.assertEqual(get_text_by_path(v3, 'b/two'), 'old contents')
@@ -167,7 +165,8 @@
         v3.unlock()
 
         # commit in subdirectory commits whole tree
-        self.run_bzr(['commit', '-m', 'commit whole tree from subdir'])
+        self.run_bzr(['commit', '-m', 'commit whole tree from subdir'],
+                     working_dir='a')
         v4 = b.repository.revision_tree(b.get_rev_id(4))
         v4.lock_read()
         self.assertEqual(get_text_by_path(v4, 'b/two'), 'new contents')

=== modified file 'bzrlib/tests/test_merge.py'
--- bzrlib/tests/test_merge.py	2012-01-02 17:59:40 +0000
+++ bzrlib/tests/test_merge.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -83,17 +83,18 @@
         tip = wt1.commit('empty commit')
         wt2 = self.make_branch_and_tree('branch2')
         wt2.pull(wt1.branch)
-        file('branch1/foo', 'wb').write('foo')
-        file('branch1/bar', 'wb').write('bar')
+        with file('branch1/foo', 'wb') as f:
+            f.write('foo')
+        with file('branch1/bar', 'wb') as f:
+            f.write('bar')
         wt1.add('foo')
         wt1.add('bar')
         wt1.commit('add foobar')
-        os.chdir('branch2')
-        self.run_bzr('merge ../branch1/baz', retcode=3)
-        self.run_bzr('merge ../branch1/foo')
-        self.assertPathExists('foo')
-        self.assertPathDoesNotExist('bar')
-        wt2 = WorkingTree.open('.') # opens branch2
+        self.run_bzr('merge ../branch1/baz', retcode=3, working_dir='branch2')
+        self.run_bzr('merge ../branch1/foo', working_dir='branch2')
+        self.assertPathExists('branch2/foo')
+        self.assertPathDoesNotExist('branch2/bar')
+        wt2 = WorkingTree.open('branch2')
         self.assertEqual([tip], wt2.get_parent_ids())
 
     def test_pending_with_null(self):

=== modified file 'bzrlib/tests/test_urlutils.py'
--- bzrlib/tests/test_urlutils.py	2011-12-18 20:46:39 +0000
+++ bzrlib/tests/test_urlutils.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -725,7 +725,7 @@
 
 
 class TestCwdToURL(TestCaseInTempDir):
-    """Test that local_path_to_url works base on the cwd"""
+    """Test that local_path_to_url works based on the cwd"""
 
     def test_dot(self):
         # This test will fail if getcwd is not ascii

=== modified file 'bzrlib/tests/test_whitebox.py'
--- bzrlib/tests/test_whitebox.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_whitebox.py	2012-01-05 13:02:31 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2008, 2009, 2011 Canonical Ltd
+# Copyright (C) 2005, 2006, 2008-2012 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,16 @@
 
 import os
 
+import bzrlib
 from bzrlib import (
+    errors,
     osutils,
+    tests,
     )
-from bzrlib.tests import TestCaseWithTransport
-from bzrlib.errors import PathNotChild
 from bzrlib.osutils import relpath, pathjoin, abspath, realpath
 
 
-class MoreTests(TestCaseWithTransport):
+class MoreTests(tests.TestCaseWithTransport):
 
     def test_relpath(self):
         """test for branch path lookups
@@ -33,52 +34,32 @@
         job: given a path (either relative to cwd or absolute), work out
         if it is inside a branch and return the path relative to the base.
         """
-        import tempfile
-
-        savedir = os.getcwdu()
         dtmp = osutils.mkdtemp()
+        self.addCleanup(osutils.rmtree, dtmp)
         # On Mac OSX, /tmp actually expands to /private/tmp
         dtmp = realpath(dtmp)
 
         def rp(p):
             return relpath(dtmp, p)
 
-        try:
-            # check paths inside dtmp while standing outside it
-            self.assertEqual(rp(pathjoin(dtmp, 'foo')), 'foo')
-
-            # root = nothing
-            self.assertEqual(rp(dtmp), '')
-
-            self.assertRaises(PathNotChild,
-                              rp,
-                              '/etc')
-
-            # now some near-miss operations -- note that
-            # os.path.commonprefix gets these wrong!
-            self.assertRaises(PathNotChild,
-                              rp,
-                              dtmp.rstrip('\\/') + '2')
-
-            self.assertRaises(PathNotChild,
-                              rp,
-                              dtmp.rstrip('\\/') + '2/foo')
-
-            # now operations based on relpath of files in current
-            # directory, or nearby
-            os.chdir(dtmp)
-
-            self.assertEqual(rp('foo/bar/quux'), 'foo/bar/quux')
-
-            self.assertEqual(rp('foo'), 'foo')
-
-            self.assertEqual(rp('./foo'), 'foo')
-
-            self.assertEqual(rp(abspath('foo')), 'foo')
-
-            self.assertRaises(PathNotChild,
-                              rp, '../foo')
-
-        finally:
-            os.chdir(savedir)
-            osutils.rmtree(dtmp)
+        # check paths inside dtmp while standing outside it
+        self.assertEqual('foo', rp(pathjoin(dtmp, 'foo')))
+
+        # root = nothing
+        self.assertEqual('', rp(dtmp))
+        self.assertRaises(errors.PathNotChild, rp, '/etc')
+
+        # now some near-miss operations -- note that
+        # os.path.commonprefix gets these wrong!
+        self.assertRaises(errors.PathNotChild, rp, dtmp.rstrip('\\/') + '2')
+        self.assertRaises(errors.PathNotChild, rp, dtmp.rstrip('\\/') + '2/foo')
+
+        # now operations based on relpath of files in current
+        # directory, or nearby
+
+        os.chdir(dtmp)
+        self.assertEqual('foo/bar/quux', rp('foo/bar/quux'))
+        self.assertEqual('foo', rp('foo'))
+        self.assertEqual('foo', rp('./foo'))
+        self.assertEqual('foo', rp(abspath('foo')))
+        self.assertRaises(errors.PathNotChild, rp, '../foo')

